==> cl01_zgf0yxnpbms-0.0.3.tar.gz: cl01_zgf0yxnpbms-0.0.3/datasink_api_client/models.py <==
from pydantic import BaseModel, Field
from typing import Optional, Any, Literal, Union, List
from uuid import UUID
from enum import Enum


class CollectionStatus(Enum):
  UNDEFINED: str = 'undefined'  # undefined
  CREATED: str = 'created'  # created
  READY: str = 'ready'  # ready
  DELETED: str = 'deleted'  # deleted
  ERROR: str = 'error'  # error


class CollectionType(Enum):
  QDRANT: str = 'qdrant'  # qdrant
  UNKNOWN: str = 'unknown'  # unknown


class DistanceMethod(Enum):
  COSINE: str = 'Cosine'  # Cosine
  EUCLIDEAN: str = 'Euclidean'  # Euclidean
  DOT: str = 'Dot'  # Dot
  MANHATTAN: str = 'Manhattan'  # Manhattan


class CollectionEntity(BaseModel):
  input: str = ...  # Input
  payload: dict = ...  # Payload
  id: Union[str, int, UUID] = ...  # Id


class CollectionEntityAlreadyExistsResponse(BaseModel):
  detail: str = 'Collection entity with this id already exists'  # Detail


class CollectionEntityListResponse(BaseModel):
  results: List['CollectionEntityResponse'] = ...  # Results
  count: int = ...  # Count


class CollectionEntityResponse(BaseModel):
  id: Union[str, int, UUID] = ...  # Id
  payload: dict = ...  # Payload


class CollectionInfo(BaseModel):
  id: Union[str, int, Any, UUID] = None  # Id
  name: str = ...  # Name
  embedding_model: 'EmbeddingModel' = ...
  collection_id: Union[UUID, Any] = None  # Collection Id
  metadata: Union['QdrantCollectionMetadata', dict] = None  # Metadata
  owner: Union[str, Any] = None  # Owner
  collection_type: CollectionType = CollectionType.QDRANT  # CollectionType
  status: CollectionStatus = CollectionStatus.UNDEFINED  # CollectionStatus


class CollectionNotFoundResponse(BaseModel):
  detail: str = 'Collection not found'  # Detail


class CollectionOrCollectionEntityNotFoundResponse(BaseModel):
  detail: str = 'Collection or collection entity not found'  # Detail


class DataPoint(BaseModel):
  input: str = ...  # Input
  payload: dict = ...  # Payload
  id: Union[str, int, UUID] = None  # Id


class EmbeddingModel(BaseModel):
  id: Union[str, int, UUID] = None  # Id
  name: str = ...  # Name
  version: str = '0.0.1'  # Version
  library: str = 'transformers'  # Library
  loaded: bool = False  # Loaded
  eb_model: Any = None  # Eb Model
  tokenizer: Any = None  # Tokenizer


class EmbeddingRequest(BaseModel):
  text: Union[str, List[str]] = ...  # Text
  eb_model_name: str = ...  # Eb Model Name
  eb_model_version: Union[str, Any] = None  # Eb Model Version


class EmbeddingResponse(BaseModel):
  embeddings: 'Embeddings' = ...  # Embeddings
  eb_model_name: str = ...  # Eb Model Name
  eb_model_version: Union[str, Any] = None  # Eb Model Version


class HTTPValidationError(BaseModel):
  detail: List['ValidationError'] = None  # Detail


class HealthCheckResponse(BaseModel):
  status: str = 'ok'  # Status


class ModelNotFoundResponse(BaseModel):
  detail: str = 'Model not found'  # Detail


class PartialCollectionInfo(BaseModel):
  id: Union[str, int, Any, UUID] = None  # Id
  name: Union[str, Any] = None  # Name
  embedding_model: Union[Any, 'PartialEmbeddingModel'] = None
  collection_id: Union[UUID, Any] = None  # Collection Id
  metadata: Union['QdrantCollectionMetadata', Any, dict] = None  # Metadata
  owner: Union[str, Any] = None  # Owner
  collection_type: Union[Any, 'CollectionType'] = None
  status: Union[Any, 'CollectionStatus'] = None


class PartialEmbeddingModel(BaseModel):
  id: Union[str, int, Any, UUID] = None  # Id
  name: Union[str, Any] = None  # Name
  version: Union[str, Any] = None  # Version
  library: Union[str, Any] = None  # Library
  loaded: Union[Any, bool] = None  # Loaded
  eb_model: Any = None  # Eb Model
  tokenizer: Any = None  # Tokenizer


class QdrantCollectionInfo(BaseModel):
  id: Union[str, int, Any, UUID] = None  # Id
  name: str = ...  # Name
  embedding_model: 'EmbeddingModel' = ...
  collection_id: Union[UUID, Any] = None  # Collection Id
  metadata: 'QdrantCollectionMetadata' = ...
  owner: Union[str, Any] = None  # Owner
  collection_type: CollectionType = CollectionType.QDRANT  # CollectionType
  status: CollectionStatus = CollectionStatus.UNDEFINED  # CollectionStatus


class QdrantCollectionMetadata(BaseModel):
  host: str = ...  # Host
  token: str = ...  # Token
  distance_method: DistanceMethod = DistanceMethod.DOT  # DistanceMethod
  dimension: Union[int, Any] = None  # Dimension


class QdrantCredentialsInvalid(BaseModel):
  detail: str = 'Qdrant credentials invalid'  # Detail


class QueryRequest(BaseModel):
  query: str = ...  # Query
  top_k: Union[int, Any] = 10  # Top K


class ReadRootResponse(BaseModel):
  status: str = 'ok'  # Status


class UnsupportedCollectionTypeResponse(BaseModel):
  detail: str = 'Unsupported collection type'  # Detail


class ValidationError(BaseModel):
  loc: List[Union[str, int]] = ...  # Location
  msg: str = ...  # Message
  type: str = ...  # Error Type

==> cl01_zgf0yxnpbms-0.0.5.tar.gz: cl01_zgf0yxnpbms-0.0.5/datasink_api_client/models.py <==
from pydantic import BaseModel, Field
from typing import Optional, Any, Literal, Union, List
from uuid import UUID
from enum import Enum


class CollectionStatus(Enum):
  UNDEFINED: str = 'undefined'  # undefined
  CREATED: str = 'created'  # created
  READY: str = 'ready'  # ready
  DELETED: str = 'deleted'  # deleted
  ERROR: str = 'error'  # error


class CollectionType(Enum):
  QDRANT: str = 'qdrant'  # qdrant
  UNKNOWN: str = 'unknown'  # unknown


class DistanceMethod(Enum):
  COSINE: str = 'Cosine'  # Cosine
  EUCLIDEAN: str = 'Euclidean'  # Euclidean
  DOT: str = 'Dot'  # Dot
  MANHATTAN: str = 'Manhattan'  # Manhattan


class CollectionEntity(BaseModel):
  input: str = ...  # Input
  payload: dict = ...  # Payload
  id: Union[int, str, UUID] = ...  # Id


class CollectionEntityAlreadyExistsResponse(BaseModel):
  detail: str = 'Collection entity with this id already exists'  # Detail


class CollectionEntityListResponse(BaseModel):
  results: List['CollectionEntityResponse'] = ...  # Results
  count: int = ...  # Count


class CollectionEntityResponse(BaseModel):
  id: Union[int, str, UUID] = ...  # Id
  payload: dict = ...  # Payload


class CollectionInfo(BaseModel):
  id: Union[int, Any, str, UUID] = None  # Id
  name: str = ...  # Name
  embedding_model: 'EmbeddingModel' = ...
  collection_id: Union[Any, UUID] = None  # Collection Id
  metadata: Union['QdrantCollectionMetadata', dict] = None  # Metadata
  owner: Union[str, Any] = None  # Owner
  collection_type: CollectionType = CollectionType.QDRANT  # CollectionType
  status: CollectionStatus = CollectionStatus.UNDEFINED  # CollectionStatus


class CollectionNotFoundResponse(BaseModel):
  detail: str = 'Collection not found'  # Detail


class CollectionOrCollectionEntityNotFoundResponse(BaseModel):
  detail: str = 'Collection or collection entity not found'  # Detail


class DataPoint(BaseModel):
  input: str = ...  # Input
  payload: dict = ...  # Payload
  id: Union[int, str, UUID] = None  # Id


class EmbeddingModel(BaseModel):
  id: Union[int, str, UUID] = None  # Id
  name: str = ...  # Name
  version: str = '0.0.1'  # Version
  library: str = 'transformers'  # Library
  loaded: bool = False  # Loaded
  eb_model: Any = None  # Eb Model
  tokenizer: Any = None  # Tokenizer


class EmbeddingRequest(BaseModel):
  text: Union[str, List[str]] = ...  # Text
  eb_model_name: str = ...  # Eb Model Name
  eb_model_version: Union[str, Any] = None  # Eb Model Version


class EmbeddingResponse(BaseModel):
  embeddings: 'Embeddings' = ...  # Embeddings
  eb_model_name: str = ...  # Eb Model Name
  eb_model_version: Union[str, Any] = None  # Eb Model Version


class HTTPValidationError(BaseModel):
  detail: List['ValidationError'] = None  # Detail


class HealthCheckResponse(BaseModel):
  status: str = 'ok'  # Status


class ModelNotFoundResponse(BaseModel):
  detail: str = 'Model not found'  # Detail


class PartialCollectionInfo(BaseModel):
  id: Union[int, Any, str, UUID] = None  # Id
  name: Union[str, Any] = None  # Name
  embedding_model: Union['PartialEmbeddingModel', Any] = None
  collection_id: Union[Any, UUID] = None  # Collection Id
  metadata: Union['QdrantCollectionMetadata', dict, Any] = None  # Metadata
  owner: Union[str, Any] = None  # Owner
  collection_type: Union[Any, 'CollectionType'] = None
  status: Union['CollectionStatus', Any] = None


class PartialEmbeddingModel(BaseModel):
  id: Union[int, Any, str, UUID] = None  # Id
  name: Union[str, Any] = None  # Name
  version: Union[str, Any] = None  # Version
  library: Union[str, Any] = None  # Library
  loaded: Union[bool, Any] = None  # Loaded
  eb_model: Any = None  # Eb Model
  tokenizer: Any = None  # Tokenizer


class QdrantCollectionInfo(BaseModel):
  id: Union[int, Any, str, UUID] = None  # Id
  name: str = ...  # Name
  embedding_model: 'EmbeddingModel' = ...
  collection_id: Union[Any, UUID] = None  # Collection Id
  metadata: 'QdrantCollectionMetadata' = ...
  owner: Union[str, Any] = None  # Owner
  collection_type: CollectionType = CollectionType.QDRANT  # CollectionType
  status: CollectionStatus = CollectionStatus.UNDEFINED  # CollectionStatus


class QdrantCollectionMetadata(BaseModel):
  host: str = ...  # Host
  token: str = ...  # Token
  distance_method: DistanceMethod = DistanceMethod.DOT  # DistanceMethod
  dimension: Union[int, Any] = None  # Dimension


class QdrantCredentialsInvalid(BaseModel):
  detail: str = 'Qdrant credentials invalid'  # Detail


class QueryRequest(BaseModel):
  query: str = ...  # Query
  top_k: Union[int, Any] = 10  # Top K


class ReadRootResponse(BaseModel):
  status: str = 'ok'  # Status


class UnsupportedCollectionTypeResponse(BaseModel):
  detail: str = 'Unsupported collection type'  # Detail


class ValidationError(BaseModel):
  loc: List[Union[str, int]] = ...  # Location
  msg: str = ...  # Message
  type: str = ...  # Error Type
